# PySoundSphere

PySoundSphere is a high level audio library written in python.

What you might be looking for:
- [Installing PySoundSphere](https://nmstr.github.io/PySoundSphere/)
- [Usage / Documentation](https://nmstr.github.io/PySoundSphere/usage/)

## Basic Installation

The default way to install PySoundSphere is using the `sounddevice` backend. To do this run the following:
```
pip install PySoundSphere[sounddevice-backend]
```
More detailed instructions are available [here](https://nmstr.github.io/PySoundSphere/). More informations about backends can be found [here](https://nmstr.github.io/PySoundSphere/backends/general/#what-are-playback-backends).

## License

This project is licensed under the GNU General Public License v3.0 (GPLv3)

See LICENSE.md for more information
